==> Descargar-App-Numeros-Primos-1.0.zip: JavaScript/modulo-numero-primo.js <==
//alert("Hola Mundo");

function Comprobar(){
	var Numero = parseFloat(document.getElementById("Texto1").value);
	var Resultado = IsPrimeNumber(Numero);
	var TextoDevuelto = "";
	if(Resultado == 0){
		TextoDevuelto = "El Número " + Numero + " es Primo.";
	}else{
		if (Resultado == 1){
			TextoDevuelto = "El Número " + Numero + " No es Primo y Tampoco es Entero.";
		}else{
			TextoDevuelto = "El Número " + Numero + " No es Primo y es Divisible por " + Resultado;
		}
	}
	document.getElementById("Resultado").innerHTML = TextoDevuelto;
}
function IsPrimeNumber(Numero){
	if (Number.isInteger(Numero) == true && Numero >= 0){
		if (Numero == 0 || Numero == 1 || Numero == 4) { 
			return 1; 
		}else{			
			if (Numero >= 4){
				if (Numero == 2 || Numero == 3 || Numero == 5 || Numero == 7 ){ return 0; }
				if (Numero % 2 == 0) { return 2; }
				if (Numero % 3 == 0) { return 3; }
				if (Numero % 5 == 0) { return 5; }
				if (Numero % 7 == 0) { return 7; }
				if (Numero >= 100 ){
					var Limite = parseInt(Math.sqrt(Numero));
					var x = 7;
					for ( x = 7; x <= Limite; x = x + 2) {
						if (Numero % x == 0) { return x; break; }
					}
				}else{
					var Limite = parseInt(Numero / 2);
					var x = 3;
					for ( x = 3; x <= Limite; x = x + 2) {
						if (Numero % x == 0) { return x; break; }
					}
				}	
			}else{
				return 0;
			}		
		}
	}else{
		return 1;
	}
	return 0;	
}

function Ir1(){
	document.getElementById("Pantalla1").style = "display: inline-block;";
	document.getElementById("Pantalla2").style = "display: none;";
}
function Ir2(){
	document.getElementById("Pantalla1").style = "display: none;";
	document.getElementById("Pantalla2").style = "display: inline-block;";
}

==> Descargar-App-Numeros-Primos-2.1.zip: JavaScript/modulo-numero-primo.js <==
//alert("Hola Mundo");

function Comprobar(){
	var Numero = parseFloat(document.getElementById("Texto1").value);
	var Resultado = IsPrimeNumber(Numero);
	var TextoDevuelto = "";
	if(Resultado == 0){
		TextoDevuelto = "El Número " + Numero + " es Primo.";
	}else{
		if (Resultado == 1){
			TextoDevuelto = "El Número " + Numero + " No es Primo.";
		}else{
			TextoDevuelto = "El Número " + Numero + " No es Primo y es Divisible por " + Resultado;
		}
	}
	document.getElementById("Resultado").innerHTML = TextoDevuelto;
}
function IsPrimeNumber(Numero){
	if (Number.isInteger(Numero) == true && Numero >= 0){
		if (Numero == 0 || Numero == 1 || Numero == 2 || Numero == 4) { 
			return 1; 
		}else{			
			if (Numero >= 4){
				if (Numero == 2 || Numero == 3 || Numero == 5 || Numero == 7 ){ return 0; }
				if (Numero % 2 == 0) { return 2; }
				if (Numero % 3 == 0) { return 3; }
				if (Numero % 5 == 0) { return 5; }
				if (Numero % 7 == 0) { return 7; }
				if (Numero >= 100 ){
					var Limite = parseInt(Math.sqrt(Numero));
					var x = 7;
					for ( x = 7; x <= Limite; x = x + 2) {
						if (Numero % x == 0) { return x; break; }
					}
				}else{
					var Limite = parseInt(Numero / 2);
					var x = 3;
					for ( x = 3; x <= Limite; x = x + 2) {
						if (Numero % x == 0) { return x; break; }
					}
				}	
			}else{
				return 0;
			}		
		}
	}else{
		return 1;
	}
	return 0;	
}

function Ir1(){
	document.getElementById("Pantalla1").style = "display: inline-block;";
	document.getElementById("Pantalla2").style = "display: none;";
}
function Ir2(){
	document.getElementById("Pantalla1").style = "display: none;";
	document.getElementById("Pantalla2").style = "display: inline-block;";
}
